@@ -47,6 +47,10 @@ void CameraUI::ProcessCropAndSend(QImage img, QPoint topLeft, bool correctVignet
 
     // Get the Amazon EC2 instance's IP and make the request to EC2
     QHostInfo ec2host = QHostInfo::fromName("mir.mhsueh.com");
+    if(ec2host.error() != QHostInfo::NoError){
+        ShowErrorConnectingDialog(0);
+        return;
+    }
     QHostAddress ec2addr = ec2host.addresses().first();
     //ocr_req = new OCRRequest("192.168.2.14", 20248, (char *) crop_filename.c_str());
 
@@ -132,6 +136,7 @@ void CameraUI::InitLangStrings(){
     langStrings["Turkish"] = "tr";
     langStrings["Ukrainian"] = "uk";
     langStrings["Vietnamese"] = "vi";
+    //langStrings["Hindi"] = "hi";
 }
 
 // Make a retranslation request
@@ -400,6 +405,8 @@ void CameraUI::send() {
 
     QPoint src_center = src_img.rect().center();
 
+
+
     emit CropObtained(croppedImage, QPoint(tl_x - src_center.x(), tl_y - src_center.y()), true);
 }
 
